@@ -42,7 +42,7 @@
 #' @references L. Ranghetti, M. Boschetti, F. Nutini, L. Busetto (2020).
 #'  "sen2r": An R toolbox for automatically downloading and preprocessing 
 #'  Sentinel-2 satellite data. _Computers & Geosciences_, 139, 104473. 
-#'  \doi{10.1016/j.cageo.2020.104473}, URL: \url{http://sen2r.ranghetti.info/}.
+#'  \doi{10.1016/j.cageo.2020.104473}, URL: \url{https://sen2r.ranghetti.info/}.
 #' @note License: GPL 3.0
 #' @importFrom httr RETRY authenticate 
 #' @importFrom foreach foreach "%do%"
@@ -145,8 +145,9 @@ s2_order <- function(
     )
   } else if (!is.na(service)) {
     s2_prodlist <- gsub(
-      "^https://scihub.copernicus.eu/((apihub)|(dhus))/odata",
-      paste0("https://scihub.copernicus.eu/",service,"/odata"),
+      "^https://((scihub)|(apihub)).copernicus.eu/((apihub)|(dhus))/odata",
+      paste0("https://",ifelse(service=="dhus","scihub","apihub"),
+             ".copernicus.eu/",service,"/odata"),
       s2_prodlist
     )
   }
@@ -198,9 +199,6 @@ s2_order <- function(
       "stored in the Long Term Archive..."
     )
   }
-  quota_exceeded <- false_invalid_safe <- FALSE # initialise variables
-  status_codes <- c()
-  
   if (!is.null(attr(s2_prodlist, "order_status")) & reorder == FALSE) {  
     # if the list includes the "order_status" attribute (meaning it was 
     # derived from a json file saved by s2_order), and reorder is FALSE,  
@@ -217,6 +215,11 @@ s2_order <- function(
     old_order <- NULL
   }
   
+  false_invalid_safe <- FALSE # initialise variables
+  quota_exceeded <- rep(TRUE, length(to_order))
+  status_codes <- c()
+  i_cred <- 1 # creds record (in case of multiple SciHub credentials)
+  
   # cycle along "to_order" to create a TRUE/FALSE array of succesfull orders
   ordered_products <- foreach(i = to_order, .combine = c) %do% {
     # delay after previous order
@@ -225,24 +228,33 @@ s2_order <- function(
     }
     
     # order products
+    # in case of user quota exceeded, repeat the order with different credentials
+    while (all(quota_exceeded[i], i_cred <= nrow(creds))) {
+      
     times_429 <- 10 # if 429 "too many requests", retry up to 10 times
     while (times_429 > 0) {
       make_order <- RETRY(
         verb = "GET",
         url = as.character(s2_prodlist[i]),
-        config = authenticate(creds[1], creds[2])
+        config = authenticate(creds[i_cred,1], creds[i_cred,2])
       )
       times_429 <-if (make_order$status_code != 429) {0} else {times_429 - 1}
     }
     
     # check if the order was successful
-    if (inherits(make_order, "response")) {
+    sel_ordered <- if (inherits(make_order, "response")) {
       # save status code
-      status_codes <- c(status_codes, make_order$status_code)
+      status_codes[i] <- make_order$status_code
       # check that user quota did not exceed
-      if (any(grepl("retrieval quota exceeded", make_order$headers$`cause-message`))) {
-        quota_exceeded <- TRUE
+      quota_exceeded[i] <- any(grepl(
+        "retrieval quota exceeded", 
+        make_order$headers$`cause-message`
+      ))
+      if (quota_exceeded[i]) {
+        i_cred <- i_cred + 1
+        message("Switching to SciHub record ",i_cred," at product ",i,".")
       }
+    
       # check that an invalid SAFE was not downloaded (#381)
       if (make_order$status_code == 200) {
         false_invalid_safe <- TRUE
@@ -250,6 +262,11 @@ s2_order <- function(
       }
       make_order$status_code == 202
     } else FALSE
+    
+    } # end of user quota WHILE cycle
+    
+    sel_ordered
+  
   }
   
   # create a temporary array as long as s2_prodlist and "fill" it with logical 
@@ -328,8 +345,8 @@ s2_order <- function(
       sum(notordered_products)," of ",sum(!nn(s2_availability), na.rm = TRUE)," Sentinel-2 images ",
       "were not correctly ordered ",
       "(HTML status code: ",unique(paste(status_codes[status_codes!=202]), collapse = ", "),")",
-      if (quota_exceeded) {paste0(
-        " because user '",creds[1],"' offline products retrieval quota exceeded. ",
+      if (any(quota_exceeded)) {paste0(
+        " because user '",creds[1,1],"' offline products retrieval quota exceeded. ",
         "Please retry later, otherwise use different SciHub credentials ",
         "(see ?write_scihub_login or set a specific value for argument \"apihub\")."
       )} else if (false_invalid_safe) {paste0(
