@@ -57,7 +57,7 @@
 #' @references L. Ranghetti, M. Boschetti, F. Nutini, L. Busetto (2020).
 #'  "sen2r": An R toolbox for automatically downloading and preprocessing 
 #'  Sentinel-2 satellite data. _Computers & Geosciences_, 139, 104473. 
-#'  \doi{10.1016/j.cageo.2020.104473}, URL: \url{http://sen2r.ranghetti.info/}.
+#'  \doi{10.1016/j.cageo.2020.104473}, URL: \url{https://sen2r.ranghetti.info/}.
 #' @note License: GPL 3.0
 #' @importFrom jsonlite fromJSON
 #' @export
@@ -298,7 +298,7 @@ s2_translate <- function(infile,
           # 2: rescale L2A in case of wrong native resolution
           # (i.e. SAFE not containing 10m bands with res = "10m")
           res_out <- if (all(
-            prod_type %in% c("SCL","CLD","SNW"),
+            sel_prod %in% c("SCL","CLD","SNW"),
             res[1] == "10m"
           )) {res[2]} else {res[1]}
           res_ratio <- min(as.integer(substr(jp2df_selbands$res,1,2))) / 
