@@ -3,12 +3,15 @@
 #'  save new username and password (`write_scihub_login()`)
 #'  or check their validity (`check_scihub_login()`).
 #'  Login information is stored in a file `apihub.txt` inside the
-#'  ".sen2r" subfolder of the home directory. This functions allow to read
-#'  or write this file, and to edit them from inside the GUI.
+#'  ".sen2r" subfolder of the home directory. This function allows reading
+#'  or writing this file, and editing it from the GUI.
+#'  In case file `apihub.txt` is missing, `read_scihub_login()` searches inside
+#'  the environmental variables `SCIHUB_USER` and `SCIHUB_PASSWORD`.
 #' @param apihub_path Path of the file in which login information is saved.
 #'  If NA (default) it is automatically read from the package default location.
 #' @param username SciHub username.
 #' @param password SciHub password.
+#' @param service Character: it can be `"dhus"` or `"apihub"` (default).
 #' @return `read_scihub_login` returns a matrix of credentials,
 #'  in which `username` is in the first column, `password` in the second.
 #' @details Notice that new/recently updated SciHub credentials are recognised by API Hub
@@ -20,7 +23,7 @@
 #' @references L. Ranghetti, M. Boschetti, F. Nutini, L. Busetto (2020).
 #'  "sen2r": An R toolbox for automatically downloading and preprocessing 
 #'  Sentinel-2 satellite data. _Computers & Geosciences_, 139, 104473. 
-#'  \doi{10.1016/j.cageo.2020.104473}, URL: \url{http://sen2r.ranghetti.info/}.
+#'  \doi{10.1016/j.cageo.2020.104473}, URL: \url{https://sen2r.ranghetti.info/}.
 #' @note License: GPL 3.0
 #' 
 #' @examples
@@ -37,7 +40,7 @@
 #' @rdname scihub_login
 #' @export
 
-read_scihub_login <- function(apihub_path=NA) {
+read_scihub_login <- function(apihub_path = NA) {
   
   # if apihub_path is not specified,
   # retrieve from the current installation
@@ -51,6 +54,8 @@ read_scihub_login <- function(apihub_path=NA) {
   # return user and password
   if (file.exists(apihub_path)) {
     t(sapply(strsplit(readLines(apihub_path), " "), c))
+  } else if (all(Sys.getenv("SCIHUB_USER") != "", Sys.getenv("SCIHUB_PASSWORD") != "")) {
+    matrix(c(Sys.getenv("SCIHUB_USER"), Sys.getenv("SCIHUB_PASSWORD")), ncol = 2)
   } else {
     # if apihub does not exists, return an error
     print_message(
@@ -73,8 +78,8 @@ read_scihub_login <- function(apihub_path=NA) {
 #' @rdname scihub_login
 #' @export
 
-check_scihub_login <- function(username, password) {
-  if (!check_scihub_connection()) {
+check_scihub_login <- function(username, password, service = "apihub") {
+  if (!check_scihub_connection(service = service)) {
     print_message(
       type = "error",
       "Impossible to reach the SciHub server ",
@@ -83,7 +88,8 @@ check_scihub_login <- function(username, password) {
   }
   check_creds <- RETRY(
     verb = "GET",
-    url = "https://scihub.copernicus.eu/apihub/odata/v1",
+    url = paste0("https://",ifelse(service=="dhus","scihub","apihub"),
+                 ".copernicus.eu/",service,"/odata/v1"),
     handle = handle(""),
     config = authenticate(username, password)
   )
@@ -100,11 +106,12 @@ check_scihub_login <- function(username, password) {
 #' @importFrom httr RETRY handle
 #' @rdname scihub_login
 #' @export
-check_scihub_connection <- function() {
+check_scihub_connection <- function(service = "apihub") {
   check_online <- try(
     RETRY(
       "GET",
-      url = "https://scihub.copernicus.eu/apihub/",
+      url = paste0("https://",ifelse(service=="dhus","scihub","apihub"),
+                   ".copernicus.eu/",service,"/"),
       handle = handle("")
     )
   )
@@ -131,16 +138,25 @@ write_scihub_login <- function(username, password,
   
   # check credentials (if required)
   if (check == TRUE) {
-    if (!check_scihub_login(username, password)) {
-      print_message(
-        type = "error",
-        "The provided credentials are not valid, ",
-        "so they will not be saved. ",
-        "Please notice that new/recently updated SciHub credentials are recognised by API Hub ",
-        "with a delay of about one week. ",
-        "For this reason, newly created SciHub credentials can not immediately be used by sen2r", 
-        "and password edits on old credentials are not immediately recognised."
-      )
+    if (!check_scihub_login(username, password, service = "apihub")) {
+      if (!check_scihub_login(username, password, service = "dhus")) {
+        print_message(
+          type = "error",
+          "The provided credentials are not valid, ",
+          "so they will not be saved. "
+        )
+      } else {
+        print_message(
+          type = "error",
+          "The provided credentials are not yet recognised by API Hub, ",
+          "although being valid on ESA SciHub; ",
+          "probably they were created recently. ",
+          "Please notice that new/recently updated SciHub credentials are recognised by API Hub ",
+          "with a delay of about one week. ",
+          "For this reason, newly created SciHub credentials can not immediately be used by sen2r", 
+          "and password edits on old credentials are not immediately recognised."
+        )
+      }
     }
   }
   
@@ -173,7 +189,7 @@ write_scihub_login <- function(username, password,
 # #' @rdname scihub_login
 
 # write dialog content
-.scihub_modal <- function() { #nocov start
+.scihub_modal <- function() { # nocov start
   
   # Define internal functions as aliases of shiny* - leaflet* ones,
   # so to avoid using "shiny::" every time
@@ -258,5 +274,4 @@ write_scihub_login <- function(username, password,
           modalButton("\u2000Cancel", icon = icon("ban")))
     )
   )
-  #nocov end
-}
+} # nocov end
