@@ -1,7 +1,6 @@
-context("Test s2_list() and safe_getMetadata(info = 'nameinfo')")
+message("\n---- Test s2_list() and safe_getMetadata(info = 'nameinfo') ----")
 testthat::skip_on_cran()
 # testthat::skip_on_travis()
-
 testthat::test_that(
   "Tests on s2_list - Error if internet is down", {
     testthat::expect_error(
@@ -21,7 +20,8 @@ testthat::test_that(
   }
 )
 
-testthat::skip_if_not(check_scihub_connection(), "SciHub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
 
 testthat::test_that(
   "Tests on s2_list - Single tile, single orbit, no pos", {
@@ -42,7 +42,7 @@ testthat::test_that(
     testthat::expect_equal(mean(s2_dt_test$clouds), 38.3432, tolerance = 1e-6)
     testthat::expect_equal(unique(s2_dt_test$online), NA)
     testthat::expect_equal(
-      grepl("^https://scihub\\.copernicus\\.eu",s2_dt_test$url),
+      grepl("^https://apihub\\.copernicus\\.eu",s2_dt_test$url),
       rep(TRUE, 3)
     )
     
@@ -59,6 +59,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Tests on s2_list - Single tile, no orbits, nopos, check availability, apihub service", {
     s2_list_test <- s2_list(
@@ -78,7 +81,7 @@ testthat::test_that(
       "list"
     )
 
-    testthat::expect_true(grepl("https://scihub.copernicus.eu/apihub/", s2_list_test[1]))
+    testthat::expect_true(grepl("https://apihub.copernicus.eu/apihub/", s2_list_test[1]))
     testthat::expect_true(min(as.Date(s2_sf_test$sensing_datetime)) >= as.Date("2017-05-01"))
     testthat::expect_true(min(as.Date(s2_sf_test$sensing_datetime)) <= as.Date("2017-05-31"))
     testthat::expect_equal(unique(s2_sf_test$id_tile), "32TNR")
@@ -88,6 +91,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Tests on s2_list - Multiple tiles, multiple orbits, pos, check availability, dhus service", {
     s2_list_test <- as.data.table(s2_list(
@@ -126,6 +132,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Tests on s2_list - single orbit, point pos, no tile, only available online", {
     pos <- sf::st_sfc(sf::st_point(c(9.85,45.81)), crs = 4326)
@@ -140,6 +149,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Tests on s2_list - Single tile, single orbit, pos, tile, only from LTA", {
     pos <- sf::st_sfc(sf::st_point(c(9.85,45.81)), crs = 4326)
@@ -155,6 +167,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Tests on s2_list - Cloudiness", {
     pos <- sf::st_sfc(sf::st_point(c(9.85,45.81)), crs = 4326)
@@ -170,6 +185,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Tests on s2_list - Single tile, multi orbit", {
     pos <- sf::st_sfc(sf::st_point(c(9.85,45.81)), crs = 4326)
@@ -184,6 +202,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Tests on s2_list - multipoint", {
     pp <- data.frame(x = c(6, 9.95),
@@ -214,6 +235,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Tests on s2_list - polygon, multiple tiles, multiple orbits", {
     pos <- sf::st_as_sfc(sf::st_bbox(
@@ -230,6 +254,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Tests on s2_list - point, single tile, large time window", {
     pos <- sf::st_sfc(sf::st_point(c(9.85,45.81)), crs = 4326)
@@ -243,6 +270,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Tests on s2_list - Single tile, multi orbit - no images", {
     pos <- sf::st_sfc(sf::st_point(c(9.85,45.81)), crs = 4326)
@@ -265,6 +295,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Tests on s2_list - Single tile, multi orbit - seasonal", {
     pos <- sf::st_sfc(sf::st_point(c(9.85,45.81)), crs = 4326)
@@ -280,6 +313,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Tests on s2_list - seasonal - single year", {
     pos <- sf::st_sfc(sf::st_point(c(9.85,45.81)), crs = 4326)
@@ -295,6 +331,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Tests on s2_list - seasonal - single year", {
     pos <- sf::st_sfc(sf::st_point(c(9.85,45.81)), crs = 4326)
@@ -311,6 +350,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Tests on s2_list - process level", {
     pos <- sf::st_sfc(sf::st_point(c(9.85,45.81)), crs = 4326)
@@ -350,6 +392,9 @@ testthat::test_that(
   }
 )
 
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
 testthat::test_that(
   "Parameter errors", {
     pos <- sf::st_sfc(sf::st_point(c(9.85,45.81)), crs = 4326)
