@@ -1,4 +1,4 @@
-context("Test s2 formats")
+message("\n---- Test s2 formats ----")
 testthat::skip_on_cran()
 # testthat::skip_on_travis()
 
