@@ -1,6 +1,7 @@
-context("Test Sen2Cor installation")
+message("\n---- Test Sen2Cor installation ----")
 testthat::skip_on_cran()
-testthat::skip_on_travis()
+testthat::skip_on_ci()
+testthat::skip_if_offline("step.esa.int")
 
 # NOTE: these tests require a high amount of time (depending on connection speed),
 # so the installation can be disabled if Sen2Cor is already installed.
@@ -120,7 +121,9 @@ testthat::test_that(
   "Test GIPP options", {
     
     # Check option previously set with test_sen2cor(use_dem = TRUE)
-    xml_sen2r_path <- normalize_path("~/.sen2r/sen2r_L2A_GIPP.xml")
+    xml_sen2r_path <- normalize_path(
+      file.path(dirname(attr(load_binpaths(), "path")), "sen2r_L2A_GIPP.xml")
+    )
     testthat::expect_true(file.exists(xml_sen2r_path))
     xml_sen2r_raw <- readLines(xml_sen2r_path)
     testthat::expect_true(grepl(
@@ -183,9 +186,9 @@ testthat::test_that(
 
 
 
-context("Test Sen2Cor")
+message("\n---- Test Sen2Cor ----")
 testthat::skip_on_cran()
-testthat::skip_on_travis()
+testthat::skip_on_ci()
 
 # NOTE: these tests require a high amount of time,
 # so running Sen2Cor is disabled by default if SAFE archives are already present.
@@ -210,7 +213,7 @@ testthat::test_that(
     if (length(s2_l2a_prod1) == 0) {
       s2_l2a_prod1 <- names(s2_download(c(
         "S2B_MSIL2A_20200801T100559_N0214_R022_T32TNR_20200801T135302.SAFE" =
-          "https://scihub.copernicus.eu/apihub/odata/v1/Products('e502d496-631f-4557-b14f-d98195fdc8c1')/$value"
+          "https://apihub.copernicus.eu/apihub/odata/v1/Products('e502d496-631f-4557-b14f-d98195fdc8c1')/$value"
       ), outdir = safe_dir
       ))
     }
