@@ -1,5 +1,6 @@
-context("check connection from main sen2r() function")
+message("\n---- check connection from main sen2r() function ----")
 testthat::skip_on_cran()
+testthat::skip_on_ci() # TODO try to remove
 
 test_that("check internet connection and fail if missing", {
   testthat::expect_error(
