@@ -1,10 +1,38 @@
-context("Test s2_merge and translate when stitching 2 tiles with no clipping")
+message("\n---- Test s2_merge and translate when stitching 2 tiles with no clipping ----")
 testthat::skip_on_cran()
-# testthat::skip_on_travis() # because required SAFE do not exists
-testthat::skip_if_not(check_scihub_connection(), "SciHub server is not reachable")
+testthat::skip_on_ci() # TODO try to remove
+testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+
+# Ensure required SAFE to be downloaded
+s2_l2a_list <- c(
+  "S2B_MSIL2A_20200801T100559_N0214_R022_T32TNR_20200801T135302.SAFE" =
+    "https://apihub.copernicus.eu/apihub/odata/v1/Products('e502d496-631f-4557-b14f-d98195fdc8c1')/$value",
+  "S2B_MSIL2A_20200801T100559_N0214_R022_T32TNS_20200801T135302.SAFE" =
+    "https://apihub.copernicus.eu/apihub/odata/v1/Products('4aac5270-bbdf-4743-9f9f-532fdbfea2fd')/$value"
+)
+suppressWarnings(s2_l2a_downloaded <- s2_download(
+  s2_l2a_list,
+  outdir = safe_dir,
+  apihub = tests_apihub_path,
+  overwrite = FALSE
+))
+
 
 testthat::test_that(
   "Tests on merge all found tiles in offline mode", {
+
+    # Check sample inputs
+    testthat::skip_if_not(file.exists(file.path(
+      safe_dir, names(s2_l2a_list[1]),
+      "GRANULE/L2A_T32TNR_A017780_20200801T101400/IMG_DATA/R10m",
+      "T32TNR_20200801T100559_B08_10m.jp2"
+    )))
+    testthat::skip_if_not(file.exists(file.path(
+      safe_dir, names(s2_l2a_list[2]),
+      "GRANULE/L2A_T32TNS_A017780_20200801T101400/IMG_DATA/R10m",
+      "T32TNS_20200801T100559_B08_10m.jp2"
+    )))
     
     outdir_1 <- tempfile(pattern = "out_test1_")
     dir.create(dirname(outdir_1), showWarnings = FALSE)
@@ -70,6 +98,9 @@ testthat::test_that(
 testthat::test_that(
   "Expect error with no extent and tiles specified in online mode", {
     
+    testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+    testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+    
     outdir_1c <- tempfile(pattern = "out_test1c_")
     dir.create(dirname(outdir_1c), showWarnings = FALSE)
     testthat::expect_error(
