@@ -1,11 +1,13 @@
-context("Test mask - main function")
+message("\n---- Test mask - main function ----")
 testthat::skip_on_cran()
-# testthat::skip_on_travis() # because required SAFE do not exists
-testthat::skip_if_not(check_scihub_connection(), "SciHub server is not reachable")
+testthat::skip_on_ci() # TODO try to remove
 
 testthat::test_that(
   "Tests on base mask on BOA", {
     
+    testthat::skip_if_not(check_scihub_connection(service = "apihub"), "API Hub server is not reachable")
+    testthat::skip_if_not(check_scihub_connection(service = "dhus"), "SciHub dhus server is not reachable")
+    
     outdir_5 <- tempfile(pattern = "out_test5_")
     dir.create(dirname(outdir_5), showWarnings = FALSE)
     exp_outpath_5 <- file.path(
